<?php

namespace Drupal\message_integration;

use Drupal\Core\Security\TrustedCallbackInterface;
use TijsVerkoyen\CssToInlineStyles\CssToInlineStyles;
use Drupal\Core\Asset\AttachedAssets;

/**
 * Provides a class that implements TrustedCallbackInterface.
 */
class MessageIntegrationPostRender implements TrustedCallbackInterface {

  /**
   * Constructs the MessageIntegrationPostRender class.
   */
  public function __construct() {}

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks(): array {
    return ['messageIntegrationPostRender'];
  }

  /**
   * Post-render callback function.
   *
   * @param string $markup
   *   The rendered element.
   * @param array $element
   *   The element which was rendered (for reference)
   *
   * @return string
   *   Markup altered as necessary.
   */
  public function messageIntegrationPostRender(string $markup, array $element): string {
    $cid = 'message_integration_css';
    $css = NULL;
    if ($cache = \Drupal::cache()->get($cid)) {
      $css = $cache->data;
    }
    else {
      $assets = AttachedAssets::createFromRenderArray([
        '#attached' => [
          'library' => [
            'core/normalize',
            'olivero/global-styling',
            'diff/diff.single_column',
            'diff/diff.colors',
            'diff/diff.general',
          ],
        ],
      ]);

      $assetResolver = \Drupal::service('asset.resolver');
      $fileSystem = \Drupal::service('file_system');
      foreach ($assetResolver->getCssAssets($assets, FALSE) as $css_asset) {
        $css .= file_get_contents($fileSystem->realpath($css_asset['data']));
      }
      \Drupal::cache()->set($cid, $css);
    }
    // For email, we don't want linked css files in the HEAD of the page, we
    // want css to be inlined into the body. So we construct a single string of
    // css, then use CssToInlineStyles() to render that css inline in the markup.
    if ($css) {
      $text = (new CssToInlineStyles())->convert($markup, $css);
    }
    return $text;
  }

}
